rustre_parser::parser::constant_decl

Function parse_one_const_decl

pub fn parse_one_const_decl<'slice, 'src>(
    input: Input<'slice, 'src, LustreLang>,
) -> IResult<'slice, 'src, LustreLang, ParserError, ParserError>
Tolerated syntax errors

  • It shouldn’t be possible to specify an initializer on a constant with multiple identifiers, but the parser accepts it nonetheless