pub fn parse_one_const_decl<'slice, 'src>(
input: Input<'slice, 'src, LustreLang>,
) -> IResult<'slice, 'src, LustreLang, ParserError, ParserError>Expand description
Tolerated syntax errors
- It shouldn’t be possible to specify an initializer on a constant with multiple identifiers, but the parser accepts it nonetheless